// Header file for mcrtime.dll
//
// Latest revision date:  12-SEP-2002
//
// This header file formally defines Masterclock, Inc.'s API for the MCRPC
// Master Clock Reference card.  The MCRPC is available in four distinct
// configurations:
//
//   MCRPC-ISA  ISA bus card, with or without integral GPS module
//   MCRPC-PCI  PCI bus card, with or without integral GPS module
//
// The primary function of the MCRPC is to provide a stable computer time
// reference.  In the absence of an integral GPS reference, the MCRPC can
// be set to an externally specified UTC time and date.  All other MCRPC
// functions are read-only.
//
// Copyright (C) 2002 Masterclock, Inc.
//
#ifndef _MCRTIME_H_
#define _MCRTIME_H_

#include "mcrdefs.h"

//////////////////////////////////////////////////////////////////////////////
//
// Exported DLL functions
//
//////////////////////////////////////////////////////////////////////////////

extern MCRTIME_API_LONG __stdcall McrGetDriverVersion(MCT_VERSION *version);
//
//  Returns driver version (major, minor, revision, and build).

extern MCRTIME_API_LONG __stdcall McrGetFwVersion(MCT_VERSION *version);
//
//  Returns MCRPC card firmware version.  Currently, only the major and
//  minor elements are relevant (revision and build are hard-coded to 0).

extern MCRTIME_API_LONG __stdcall McrGetFwChecksum(MCT_CHECKSUM *checksum);
//
//  Returns MCRPC card firmware checksum.

extern MCRTIME_API_LONG __stdcall McrGetHwSignature(char *signature, size_t size);
//
//  Returns an ASCII signature string from the MCRPC card.  This is
//  primarily of interest to the device driver; it's exported via this
//  API primarily for "completeness".

extern MCRTIME_API_LONG __stdcall McrGetHwStatus(MCT_HW_STATUS *status);
//
//  Returns general MCRPC card hardware status information.  Probably
//  the most useful element here is activeReference, which can be read
//  to determine whether time can be set (activeReference == RT_OBC).

extern MCRTIME_API_LONG __stdcall McrGetSignalQuality(MCT_SIGNAL_QUALITY *sq);
//
//  Returns information about which satellites are currently being seen
//  by the GPS receiver, including signal-to-noise ratio for each.
//  For a good GPS fix, a minimum of three satellites should be in use
//  at any given moment.  The MCRPC card automatically switches its
//  active time reference based on the GPS module's internal assessment.
//  (To avoid any disruption in available date and time, the local on-board
//  clock is slaved to the GPS time while the GPS is the time reference.)

extern MCRTIME_API_LONG __stdcall McrGetPosition(MCT_POSITION *position);
//
//  Returns the GPS antenna's position, altitude, true course, and speed.

extern MCRTIME_API_LONG __stdcall McrGetTime(MCT_TIME *time);
//
//  Returns UTC date and time, to the nearest millisecond.
//  Also returns the corresponding system time (FILETIME compatible); this
//  is done to facilitate precise time offset determinations.
//
//  If software latency is a concern, a precision performance counter value
//  also is available.  This represents a QueryPerformanceCounter() value as
//  sampled at the turn of each second (i.e. as of 0 milliseconds).
//
//  NOTE 1:  Normal year range is 2000-2099; however, if no valid date is
//           returned from the card, a 1980 date may result.
//
//  NOTE 2:  Leap second events always occur on the last second of the day.
//           A leap second day will be one second shorter or longer than
//           normal; in the latter case, a valid time of 23:59:60 can appear.

extern MCRTIME_API_LONG __stdcall McrSetTime(MCT_SETTABLE_TIME *time);
//
//  Sets new UTC date and time into the MCRPC card.  Relative to subsequent
//  calls to McrGetTime, the effect is immediate.  However, behind the
//  scenes, it can take as long as two seconds for the new time and date
//  to latch into the MCRPC card hardware; during the interim, per second
//  ticks are temporarily referenced to the time-set event, instead of to
//  tick interrupts from the card.  (The reason for part of this delay is
//  to ensure that subsequent ticks from the card will be time-aligned with
//  the time-set event.)
//
//  Bogus date/time values are ignored silently.

#endif
